[tor-commits] [tor/main] Only apply more frequent cwnd updates after slow start.

dgoulet at torproject.org dgoulet at torproject.org
Tue Feb 22 20:48:20 UTC 2022


commit d62f9c9d0058ba3bfa8fe226c697abb05a477c5a
Author: Mike Perry <mikeperry-git at torproject.org>
Date:   Fri Jan 21 23:20:52 2022 +0000

    Only apply more frequent cwnd updates after slow start.
---
 src/core/or/congestion_control_st.h | 10 ++++++++--
 1 file changed, 8 insertions(+), 2 deletions(-)

diff --git a/src/core/or/congestion_control_st.h b/src/core/or/congestion_control_st.h
index 0d6bf0b662..ea80868350 100644
--- a/src/core/or/congestion_control_st.h
+++ b/src/core/or/congestion_control_st.h
@@ -206,7 +206,8 @@ struct congestion_control_t {
  *
  * Congestion control literature recommends only one update of cwnd per
  * cwnd worth of acks. However, we can also tune this to be more frequent
  * by increasing the 'cc_cwnd_inc_rate' consensus parameter.
  *
  * If this returns 0 due to high cwnd_inc_rate, the calling code will
  * update every sendme ack.
@@ -215,8 +216,13 @@ static inline uint64_t CWND_UPDATE_RATE(const struct congestion_control_t *cc)
 {
   /* We add cwnd_inc_rate*sendme_inc/2 to round to nearest integer number
    * of acks */
-  return ((cc->cwnd + cc->cwnd_inc_rate*cc->sendme_inc/2)
+
+  if (cc->in_slow_start) {
+    return ((cc->cwnd + cc->sendme_inc/2)/cc->sendme_inc);
+  } else {
+    return ((cc->cwnd + cc->cwnd_inc_rate*cc->sendme_inc/2)
            / (cc->cwnd_inc_rate*cc->sendme_inc));
+  }
 }
 
 /**
@@ -206,7 +206,8 @@ struct congestion_control_t {
  * Congestion control literature recommends only one update of cwnd per
  * cwnd worth of acks. However, we can also tune this to be more frequent
- * by increasing the 'cc_cwnd_inc_rate' consensus parameter.
+ * by increasing the 'cc_cwnd_inc_rate' consensus parameter. This tuning
+ * only applies after slow start.
  *
  * If this returns 0 due to high cwnd_inc_rate, the calling code will





More information about the tor-commits mailing list